%global pypi_name postorius

Name:           postorius
Version:        1.0.0
Release:        0.5.bzr147%{?dist}
Summary:        Web user interface for GNU Mailman

License:        GPLv3
URL:            https://launchpad.net/postorius
#Source0:        https://launchpad.net/%{name}/trunk/%{version}a1/+download/%{name}-%{version}a.tar.gz
# bzr export for mailmanclient compatibility
Source0:        %{name}-%{version}-bzr147.tar.gz

# To get SOURCE1:
#   bzr branch lp:~mailman-coders/postorius/postorius_standalone
#   tar -czf postorius_standalone-%{version}.tar.gz postorius_standalone
Source1:        postorius_standalone-%{version}.tar.gz

Source2:        postorius.apache.conf
Source3:        postorius.MANIFEST

# https://bugs.launchpad.net/postorius/+bug/1175967
Patch1:         postorius-owners.patch
Patch2:         postorius-fix-unittests.patch


BuildArch:      noarch

BuildRequires:  python-devel
BuildRequires:  python-sphinx
BuildRequires:  django-social-auth
BuildRequires:  python-mailman-client
BuildRequires:  python-mock
%if 0%{fedora} && 0%{fedora} < 18
BuildRequires:  Django
BuildRequires:  Django-south
%else
BuildRequires:  python-django
BuildRequires:  python-django-south
%endif

Requires:       django-social-auth >= 0.7.8
Requires:       python-mailman-client
%if 0%{fedora} && 0%{fedora} < 18
Requires:       Django >= 1.3
%else
Requires:       python-django >= 1.3
%endif


%description
The Postorius Django app provides a web user interface to access GNU Mailman.

%prep
%setup -q -n %{pypi_name} -a 1
cp -p %{SOURCE3} MANIFEST.in
%patch1 -p0 -b .owners
%patch2 -p0 -b .fix-unittests
# Remove bundled egg-info
rm -rf src/%{pypi_name}.egg-info
# remove shebang on manage.py
sed -i -e '1d' postorius_standalone/manage.py
# remove executable permissions on wsgi script
chmod -x postorius_standalone/srv/postorius.wsgi
# remove __init__.py in postorius_standalone to prevent it from being
# installed (find_package won't find it). It's empty anyway.
rm -f postorius_standalone/__init__.py


%build
%{__python} setup.py build

# generate html docs
sphinx-build src/postorius/doc html
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}


%install
%{__python} setup.py install --skip-build --root %{buildroot}

# Install the Django files
mkdir -p %{buildroot}%{_sysconfdir}/%{name}/sites/default
cp -p postorius_standalone/{manage,settings,urls}.py \
    %{buildroot}%{_sysconfdir}/%{name}/sites/default/
cp -pr postorius_standalone/srv %{buildroot}%{_sysconfdir}/%{name}/sites/default/
touch --reference postorius_standalone/manage.py \
    %{buildroot}%{_sysconfdir}/%{name}/sites/default/__init__.py
# Apache HTTPd config file
install -p -D -m 644 %{SOURCE2} %{buildroot}/%{_sysconfdir}/httpd/conf.d/postorius.conf
# Localstate directory
mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}/sites/default/static
mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}/sites/default/db
# Remove the doc from the site-packages dir
rm -rf %{python_sitelib}/%{name}/doc


%check
touch postorius_standalone/__init__.py
%{__python} postorius_standalone/manage.py test --pythonpath=`pwd`/src postorius
rm -f postorius_standalone/__init__.py


%post
# Build the static files cache
%{__python} %{_sysconfdir}/%{name}/sites/default/manage.py \
    collectstatic --noinput >/dev/null || :


%preun
# The static files are a cache and can be removed with the package
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    rm -rf %{_localstatedir}/lib/%{name}/sites/default/static
fi


%files
%doc html README.rst COPYING
%config(noreplace) %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/httpd/conf.d/postorius.conf
%{python_sitelib}/%{name}
%{python_sitelib}/%{pypi_name}-*-py?.?.egg-info
%dir %{_localstatedir}/lib/%{name}
%dir %{_localstatedir}/lib/%{name}/sites
%dir %{_localstatedir}/lib/%{name}/sites/default
%dir %{_localstatedir}/lib/%{name}/sites/default/static
%attr(755,apache,apache) %{_localstatedir}/lib/%{name}/sites/default/db


%changelog
* Wed Jul 24 2013 Aurelien Bompard <abompard@fedoraproject.org> - 1.0.0-0.5.bzr147
- update to BZR rev 147
- drop patch 0

* Wed Mar 27 2013 Aurelien Bompard <abompard@fedoraproject.org> - 1.0.0-0.1.a1
- initial package
